package br.exemplogoogleplus.thiengo;

import java.util.ArrayList;
import java.util.List;

import android.app.Activity;
import android.content.Intent;
import android.content.IntentSender.SendIntentException;
import android.os.Bundle;
import android.widget.ListView;
import br.exemplogoogleplus.thiengo.adapter.UsersAdapter;
import br.exemplogoogleplus.thiengo.domain.User;

import com.google.android.gms.common.ConnectionResult;
import com.google.android.gms.common.GooglePlayServicesUtil;
import com.google.android.gms.common.api.CommonStatusCodes;
import com.google.android.gms.common.api.GoogleApiClient;
import com.google.android.gms.common.api.GoogleApiClient.ConnectionCallbacks;
import com.google.android.gms.common.api.GoogleApiClient.OnConnectionFailedListener;
import com.google.android.gms.common.api.PendingResult;
import com.google.android.gms.common.api.ResultCallback;
import com.google.android.gms.plus.People;
import com.google.android.gms.plus.People.LoadPeopleResult;
import com.google.android.gms.plus.Plus;
import com.google.android.gms.plus.model.people.PersonBuffer;

public class UsersActivity extends Activity implements ConnectionCallbacks, OnConnectionFailedListener {
	private static final int SIGN_IN_CODE = 56465;
	private GoogleApiClient googleApiClient;
	private ConnectionResult connectionResult;
	
	private boolean isConsentScreenOpened;
	private boolean isSignInButtonClicked;
	
	private List<User> list;
	
    // VIEWS
    	private ListView listView;
	
	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_users);
		
		list = new ArrayList<User>();
		accessViews();
		
		googleApiClient = new GoogleApiClient.Builder(UsersActivity.this)
			.addConnectionCallbacks(UsersActivity.this)
			.addOnConnectionFailedListener(UsersActivity.this)
			.addApi(Plus.API)
			.addScope(Plus.SCOPE_PLUS_LOGIN)
			.build();
	}

	
	@Override
	public void onStart(){
		super.onStart();
		
		if(googleApiClient != null){
			googleApiClient.connect();
		}
	}
	
	
	@Override
	public void onStop(){
		super.onStop();
		
		if(googleApiClient != null && googleApiClient.isConnected()){
			googleApiClient.disconnect();
		}
	}
	
	
	@Override
	public void onResume(){
		super.onResume();
	}
	
	
	@Override
	public void onActivityResult(int requestCode, int resultCode, Intent data){
		if(requestCode == SIGN_IN_CODE){
			isConsentScreenOpened = false;
			
			if(resultCode != RESULT_OK){
				isSignInButtonClicked = false;
			}
			
			if(!googleApiClient.isConnecting()){
				googleApiClient.connect();
			}
		}
	}
	
	
	
	
	
	
	
	
	// UTIL
		public void accessViews(){
			listView = (ListView) findViewById(R.id.listView);
		}
		
		public void resolveSignIn(){
			if(connectionResult != null && connectionResult.hasResolution()){
				try {
					isConsentScreenOpened = true;
					connectionResult.startResolutionForResult(UsersActivity.this, SIGN_IN_CODE);
				}
				catch(SendIntentException e) {
					isConsentScreenOpened = false;
					googleApiClient.connect();
				}
			}
		}
		
		public void getDataProfile(){
			// USER LIST
				PendingResult<People.LoadPeopleResult> loadPeopleResult = Plus.PeopleApi.loadVisible(googleApiClient, null);
				loadPeopleResult.setResultCallback(new ResultCallback<People.LoadPeopleResult>(){
					@Override
					public void onResult(LoadPeopleResult result) {
						if(result.getStatus().getStatusCode() == CommonStatusCodes.SUCCESS){
							PersonBuffer pb = result.getPersonBuffer();
							try{
								for(int i = 0, tamI = pb.getCount(); i < tamI; i++){
									User u = new User();
									u.setId(pb.get(i).getId());
									u.setName(pb.get(i).getDisplayName());
									u.setUrl(pb.get(i).getImage().getUrl());
									list.add(u);
								}
							}
							finally{
								pb.close();
								listView.setAdapter(new UsersAdapter(UsersActivity.this, list));
							}
						}
					}
				});
		}
		
		
	
		
		
		
		
	// LISTENERS
		@Override
		public void onConnected(Bundle connectionHint) {
			isSignInButtonClicked = false;
			getDataProfile();
		}


		@Override
		public void onConnectionSuspended(int cause) {
			googleApiClient.connect();
		}


		@Override
		public void onConnectionFailed(ConnectionResult result) {
			if(!result.hasResolution()){
				GooglePlayServicesUtil.getErrorDialog(result.getErrorCode(), UsersActivity.this, 0).show();
				return;
			}
			
			if(!isConsentScreenOpened){
				connectionResult = result;
				
				if(isSignInButtonClicked){
					resolveSignIn();
				}
			}
		}
}
